@@ -144,6 +144,7 @@ static const FFInputFormat * const demuxer_list[] = {
     &ff_kux_demuxer,
     &ff_kvag_demuxer,
     &ff_laf_demuxer,
+    &ff_lc3_demuxer,
     &ff_lmlm4_demuxer,
     &ff_loas_demuxer,
     &ff_luodat_demuxer,
@@ -227,6 +228,7 @@ static const FFInputFormat * const demuxer_list[] = {
     &ff_qoa_demuxer,
     &ff_r3d_demuxer,
     &ff_rawvideo_demuxer,
+    &ff_rcwt_demuxer,
     &ff_realtext_demuxer,
     &ff_redspark_demuxer,
     &ff_rka_demuxer,
